@@ -1,5 +1,5 @@
 /* Utility to help print --version output in a consistent format.
-   Copyright (C) 1999, 2000 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,12 +30,12 @@
 #else
 # define _(Text) Text
 #endif
-#define N_(Text) Text
 
 /* Default copyright goes to the FSF. */
 
 char* version_etc_copyright =
-  N_("Copyright (C) 2000 Free Software Foundation, Inc.");
+  /* Do *not* mark this string for translation.  */
+  "Copyright (C) 2001 Free Software Foundation, Inc.";
 
 
 /* Display the --version information the standard way.
@@ -60,7 +60,7 @@ version_etc (FILE *stream,
   fprintf (stream, _("Written by %s.\n"), authors);
   putc ('\n', stream);
 
-  fputs (_(version_etc_copyright), stream);
+  fputs (version_etc_copyright, stream);
   putc ('\n', stream);
 
   fputs (_("\
