@@ -40,7 +40,7 @@
 /* The official name of this program (e.g., no `g' prefix).  */
 #define PROGRAM_NAME "csplit"
 
-#define AUTHORS "Stuart Kemp and David MacKenzie"
+#define AUTHORS N_ ("Stuart Kemp and David MacKenzie")
 
 #ifdef STDC_HEADERS
 # include <stdlib.h>
