@@ -58,7 +58,7 @@
 
 typedef long COST;
 
-#define MAXCOST	(~(((unsigned long) 1) << (8 * sizeof (COST) -1)))
+#define MAXCOST	TYPE_MAXIMUM (COST)
 
 #define SQR(n)		((n) * (n))
 #define EQUIV(n)	SQR ((COST) (n))
@@ -117,11 +117,10 @@ typedef long COST;
 
 /* Miscellaneous definitions.  */
 
-typedef unsigned int bool;
 #undef TRUE
-#define TRUE	1
+#define TRUE true
 #undef FALSE
-#define FALSE	0
+#define FALSE false
 
 /* Word descriptor structure.  */
 
@@ -133,8 +132,8 @@ struct Word
     /* Static attributes determined during input.  */
 
     const char *text;		/* the text of the word */
-    short length;		/* length of this word */
-    short space;		/* the size of the following space */
+    int length;			/* length of this word */
+    int space;			/* the size of the following space */
     bool paren:1;		/* starts with open paren */
     bool period:1;		/* ends in [.?!])* */
     bool punct:1;		/* ends in punctuation */
@@ -142,7 +141,7 @@ struct Word
 
     /* The remaining fields are computed during the optimization.  */
 
-    short line_length;		/* length of the best line starting here */
+    int line_length;		/* length of the best line starting here */
     COST best_cost;		/* cost of best paragraph starting here */
     WORD *next_break;		/* break which achieves best_cost */
   };
@@ -188,8 +187,7 @@ static bool uniform;
 static const unsigned char *prefix;
 
 /* User-supplied maximum line width (default WIDTH).  The only output
-   lines
-   longer than this will each comprise a single word.  */
+   lines longer than this will each comprise a single word.  */
 static int max_width;
 
 /* Values derived from the option values.  */
@@ -326,13 +324,16 @@ main (register int argc, register char **argv)
 
   if (argc > 1 && argv[1][0] == '-' && ISDIGIT (argv[1][1]))
     {
+      const char *s = argv[1] + 1;
       max_width = 0;
       /* Old option syntax; a dash followed by one or more digits.
          Move past the number. */
-      for (++argv[1]; ISDIGIT (*argv[1]); ++argv[1])
+      for (; ISDIGIT (*s); ++s)
 	{
-	  /* FIXME: use strtol to detect overflow.  */
-	  max_width = max_width * 10 + *argv[1] - '0';
+	  int old_max = max_width;
+	  max_width = max_width * 10 + *s - '0';
+	  if (INT_MAX / 10 < old_max || max_width < old_max)
+	    error (EXIT_FAILURE, 0, _("invalid width option: `%s'"), argv[1]);
 	}
       /* Make the options we just parsed invisible to getopt. */
       argv[1] = argv[0];
@@ -372,7 +373,7 @@ main (register int argc, register char **argv)
 	  long int tmp_long;
 	  if (xstrtol (optarg, NULL, 10, &tmp_long, "") != LONGINT_OK
 	      || tmp_long <= 0 || tmp_long > INT_MAX)
-	    error (EXIT_FAILURE, 0, _("invalid line number increment: `%s'"),
+	    error (EXIT_FAILURE, 0, _("invalid width: `%s'"),
 		   optarg);
 	  max_width = (int) tmp_long;
 	}
@@ -815,6 +816,14 @@ fmt_paragraph (void)
 	      start->next_break = w;
 	      start->line_length = len;
 	    }
+
+	  /* This is a kludge to keep us from computing `len' as the
+	     sum of the sentinel length and some non-zero number.
+	     Since the sentinel w->length may be INT_MAX, adding
+	     to that would give a negative result.  */
+	  if (w == word_limit)
+	    break;
+
 	  len += (w - 1)->space + w->length;	/* w > start >= word */
 	}
       while (len < max_width);
