@@ -51,7 +51,7 @@ tac -r -s '.\|
 /* The official name of this program (e.g., no `g' prefix).  */
 #define PROGRAM_NAME "tac"
 
-#define AUTHORS "Jay Lepreau and David MacKenzie"
+#define AUTHORS N_ ("Jay Lepreau and David MacKenzie")
 
 #if defined __MSDOS__ || defined _WIN32
 /* Define this to non-zero on systems for which the regular mechanism
